@@ -50,18 +50,18 @@ class CaseFrames:
         self.name = ''
 
         self._attributes = []
-        for attribute, _list in struct.items():
+        for attribute, list_ in struct.items():
             if attribute not in ATTRIBUTES:
                 # ? Should we support custom attributes?
                 continue
 
             if attribute == "version" or attribute == "baseMVA":
-                setattr(self, attribute, _list)
+                setattr(self, attribute, list_)
             elif attribute in ['bus_name', 'branch_name', 'gen_name']:
-                idx = pd.Index(_list, name=attribute)
+                idx = pd.Index(list_, name=attribute)
                 setattr(self, attribute, idx)
             else:
-                cols = _list.shape[1]
+                cols = list_.shape[1]
                 # NOTE: .get('key') instead of ['key'] to default range
                 columns = COLUMNS.get(attribute, [i for i in range(0, cols)])
                 columns = columns[:cols]
@@ -73,7 +73,7 @@ class CaseFrames:
                     columns = (columns[:-1]
                                + ["{}_{}".format(columns[-1], i)
                                   for i in range(cols - len(columns), -1, -1)])
-                df = pd.DataFrame(_list, columns=columns)
+                df = pd.DataFrame(list_, columns=columns)
                 setattr(self, attribute, df)
 
             self._attributes.append(attribute)
@@ -94,15 +94,15 @@ class CaseFrames:
                 continue
 
             # TODO: migrate using GridCal approach
-            _list = parse_file(attribute, string)
-            if _list is not None:
+            list_ = parse_file(attribute, string)
+            if list_ is not None:
                 if attribute == "version" or attribute == "baseMVA":
-                    setattr(self, attribute, _list[0][0])
+                    setattr(self, attribute, list_[0][0])
                 elif attribute in ['bus_name', 'branch_name', 'gen_name']:
-                    idx = pd.Index(_list, name=attribute)
+                    idx = pd.Index([name[0] for name in list_], name=attribute)
                     setattr(self, attribute, idx)
                 else:
-                    cols = max([len(l) for l in _list])
+                    cols = max([len(l) for l in list_])
                     # NOTE: .get('key') instead of ['key'] to default range
                     columns = COLUMNS.get(attribute, [i for i in range(0, cols)])
                     columns = columns[:cols]
@@ -114,7 +114,7 @@ class CaseFrames:
                         columns = (columns[:-1]
                                    + ["{}_{}".format(columns[-1], i)
                                       for i in range(cols - len(columns), -1, -1)])
-                    df = pd.DataFrame(_list, columns=columns)
+                    df = pd.DataFrame(list_, columns=columns)
 
                     setattr(self, attribute, df)
                 self._attributes.append(attribute)
@@ -123,28 +123,42 @@ class CaseFrames:
         if 'bus_name' in self._attributes:
             self.bus.set_index(self.bus_name, drop=False, inplace=True)
         else:
-            self.bus.set_index(
-                pd.RangeIndex(
-                    1, len(
-                        self.bus.index) + 1, 1), drop=False, inplace=True)
+            self.bus.set_index(pd.RangeIndex(1, len(self.bus.index) + 1),
+                               drop=False, inplace=True)
 
         if 'branch_name' in self._attributes:
             self.branch.set_index(self.branch_name, drop=False, inplace=True)
         else:
-            self.branch.set_index(
-                pd.RangeIndex(
-                    1, len(
-                        self.branch.index) + 1, 1), drop=False, inplace=True)
+            self.branch.set_index(pd.RangeIndex(1, len(self.branch.index) + 1),
+                                  drop=False, inplace=True)
 
         if 'gen_name' in self._attributes:
             self.gen.set_index(self.gen_name, drop=False, inplace=True)
             self.gencost.set_index(self.gen_name, drop=False, inplace=True)
         else:
-            self.gen.set_index(
-                pd.RangeIndex(
-                    1, len(
-                        self.gen.index) + 1, 1), drop=False, inplace=True)
-            self.gencost.set_index(
-                pd.RangeIndex(
-                    1, len(
-                        self.gen.index) + 1, 1), drop=False, inplace=True)
+            self.gen.set_index(pd.RangeIndex(1, len(self.gen.index) + 1),
+                               drop=False, inplace=True)
+            self.gencost.set_index(pd.RangeIndex(1, len(self.gen.index) + 1),
+                                   drop=False, inplace=True)
+
+    def to_excel(self, path):
+        with pd.ExcelWriter(path) as writer:
+            pd.DataFrame(                
+                data={
+                    'INFO': {
+                        'version': getattr(self, 'version'),
+                        'baseMVA': getattr(self, 'baseMVA'),
+                    }
+                }
+            ).to_excel(writer, sheet_name='info')
+            for attribute in self._attributes:
+                if attribute == "version" or attribute == "baseMVA":
+                    # TODO: make self._attributes_non_pandas?
+                    continue
+                elif attribute in ['bus_name', 'branch_name', 'gen_name']:
+                    pd.DataFrame(data={
+                        attribute: getattr(self, attribute)
+                    }).to_excel(writer, sheet_name=attribute)
+                else:
+                    getattr(self, attribute).to_excel(writer,
+                                                      sheet_name=attribute)
